
require 'uri'
require 'net/http'
require 'json'

module AptlyAPI
	##
	# This class represents an Aptly Package
	class Package
		##
		# Creates a new Package definitation with data +json+ located on +server+
		def initialize(server, json)
			@server = server
			@http = Net::HTTP.new(@server.host, @server.port)

			info = hget("/api/packages/#{json}")

			if !info.is_a?(Integer)
				@name = info['Package']
				@description = info['Description']
            	@architecture = info['Architecture']
				@priority = info['Priority']
				@version = info['Version']
			end
		end

		attr_reader :name, :description, :architecture, :priority, :version

	protected
		##
		# Get an hash of JSON data from server +path+
		def hget(path)
			request = Net::HTTP::Get.new("#{@server.path}#{URI.escape(path)}")
			response = @http.request(request)
			if response.code.to_i != 200
				return response.code.to_i
			end
			return JSON.parse(response.body)
		end

		##
		# Post +data+ hash to +path+ as JSON
		def hpost(path, data)
			request = Net::HTTP::Post.new("#{@server.path}#{URI.escape(path)}")
			request.add_field('Content-Type', 'application/json')
			request.body = data.to_json
			response = @http.request(request)
			return response.code.to_i
		end

		##
		# Put +data+ hash to +path+ as JSON
		def hput(path, data)
			request = Net::HTTP::Put.new("#{@server.path}#{URI.escape(path)}")
			request.add_field('Content-Type', 'application/json')
			request.body = data.to_json
			response = @http.request(request)
			return response.code.to_i
		end

		##
		# Sends HTTP delete call to +path+
		def hdelete(path)
			request = Net::HTTP::Delete.new("#{@server.path}#{URI.escape(path)}")
			response = @http.request(request)
			return response.code.to_i
		end
	end
end
